[Mplayer-cvslog] CVS: main/libvo geometry.c,1.3,1.4 geometry.h,1.2,1.3 vo_fbdev.c,1.75,1.76 vo_tdfxfb.c,1.22,1.23 vo_xv.c,1.131,1.132

JALH CVS (Mark Zealey) mark at mplayerhq.hu
Fri Jan 3 21:46:47 CET 2003


Update of /cvsroot/mplayer/main/libvo
In directory mail:/var/tmp.root/cvs-serv25359/libvo

Modified Files:
	geometry.c geometry.h vo_fbdev.c vo_tdfxfb.c vo_xv.c 
Log Message:
Added support for X style -geometry options (adapted from Henk's patch)
-- Mark


Index: geometry.h
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/geometry.h,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- geometry.h	23 Oct 2002 18:51:19 -0000	1.2
+++ geometry.h	3 Jan 2003 20:46:44 -0000	1.3
@@ -3,6 +3,7 @@
 #define __GEOMETRY_H
 
 extern char *vo_geometry;
-int geometry(int *xpos, int *ypos, int scrw, int scrh, int vidw, int vidh, int fs);
+int geometryFull(int *pwidth, int *pheight, int *xpos, int *ypos, int scrw, int scrh, int vidw, int vidh);
+int geometry(int *xpos, int *ypos, int scrw, int scrh, int vidw, int vidh);
 
 #endif /* !__GEOMETRY_H */

Index: vo_fbdev.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_fbdev.c,v
retrieving revision 1.75
retrieving revision 1.76
diff -u -r1.75 -r1.76
--- vo_fbdev.c	11 Nov 2002 15:20:25 -0000	1.75
+++ vo_fbdev.c	3 Jan 2003 20:46:44 -0000	1.76
@@ -1039,7 +1039,7 @@
 		image_width=width;
 		image_height=height;
 	    }
-		geometry(&x_offset,&y_offset,fb_xres,fb_yres,image_width,image_height,fs);
+		geometry(&x_offset,&y_offset,fb_xres,fb_yres,image_width,image_height);
 
 		if(vidix_init(width,height,x_offset,y_offset,image_width,
 			    image_height,format,fb_bpp,
@@ -1063,7 +1063,7 @@
 		return 1;
 	    }
 
-	    geometry(&x_offset,&y_offset,fb_xres,fb_yres,out_width,out_height,fs);
+	    geometry(&x_offset,&y_offset,fb_xres,fb_yres,out_width,out_height);
 
 	    L123123875 = frame_buffer + (out_width - in_width) * fb_pixel_size /
 		    2 + ( (out_height - in_height) / 2 ) * fb_line_len +

Index: vo_tdfxfb.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_tdfxfb.c,v
retrieving revision 1.22
retrieving revision 1.23
diff -u -r1.22 -r1.23
--- vo_tdfxfb.c	11 Nov 2002 15:20:26 -0000	1.22
+++ vo_tdfxfb.c	3 Jan 2003 20:46:44 -0000	1.23
@@ -204,7 +204,7 @@
 static void setup_screen(uint32_t full)
 {
 	aspect(&vidwidth, &vidheight, full ? A_ZOOM : A_NOZOOM);
-	geometry(&vidx, &vidy, screenwidth, screenheight, vidwidth, vidheight, full);
+	geometry(&vidx, &vidy, screenwidth, screenheight, vidwidth, vidheight);
 	vo_fs = full;
 	clear_screen();
 }

Index: vo_xv.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_xv.c,v
retrieving revision 1.131
retrieving revision 1.132
diff -u -r1.131 -r1.132
--- vo_xv.c	3 Jan 2003 18:33:26 -0000	1.131
+++ vo_xv.c	3 Jan 2003 20:46:44 -0000	1.132
@@ -282,7 +282,7 @@
  vo_mouse_autohide=1;
 
  vo_dx=( vo_screenwidth - d_width ) / 2; vo_dy=( vo_screenheight - d_height ) / 2;
- geometry(&vo_dx, &vo_dy, vo_screenwidth, vo_screenheight, d_width, d_height,0);
+ geometry(&vo_dx, &vo_dy, vo_screenwidth, vo_screenheight, d_width, d_height);
  vo_dwidth=d_width; vo_dheight=d_height;
      
 #ifdef HAVE_XF86VM



More information about the MPlayer-cvslog mailing list
Index: geometry.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/geometry.c,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- geometry.c	23 Nov 2002 10:58:07 -0000	1.3
+++ geometry.c	3 Jan 2003 20:46:44 -0000	1.4
@@ -4,80 +4,58 @@
 #include "../mp_msg.h"
 #include "../mplayer.h" /* exit_player() */
 #include <string.h>
-#include <stdlib.h> /* strtol */
 
 /* A string of the form xpos[%]:ypos[%] */
 char *vo_geometry = NULL;
 
 int geometry_error()
 {
-	mp_msg(MSGT_VO, MSGL_ERR, "-geometry option format incorrect (%s)\n", vo_geometry);
+	mp_msg(MSGT_VO, MSGL_ERR, "-geometry must be in [WxH][+X+Y] | [X[%%]:[Y[%%]]] format, incorrect (%s)\n", vo_geometry);
 	exit_player(NULL);		/* ????? what else could we do ? */
 	return 0;
 }
 
-int get_num(char *s, int *num, char *end)
+// A little kludge as to not to have to update all drivers
+// Only the vo_xv driver supports now the full [WxH][+X+Y] option
+int geometryFull(int *pwidth, int *pheight, int *xpos, int *ypos, int scrw, int scrh, int vidw, int vidh)
 {
-	char *e;
-	long int t;
+        int width, height, xoff, yoff, xper, yper;
 
-	t = strtol(s, &e, 10);
+	width = height = xoff = yoff = xper = yper = -1;
 
-	if(e != end)
-		return 0;
+	/* no need to save a few extra cpu cycles here ;) */
+	/* PUKE i will rewrite this code sometime maybe - euck but it works */
+        if(vo_geometry != NULL) {
+		if(sscanf(vo_geometry, "%ix%i+%i+%i", &width, &height, &xoff, &yoff) != 4 &&
+		   sscanf(vo_geometry, "%ix%i", &width, &height) != 2 &&
+		   sscanf(vo_geometry, "+%i+%i", &xoff, &yoff) != 2 &&
+		   sscanf(vo_geometry, "%i:%i", &xoff, &yoff) != 2 &&
+		   sscanf(vo_geometry, "%i:%i%%", &xper, &yper) != 2 &&
+		   sscanf(vo_geometry, "%i%%:%i", &xper, &yper) != 2 &&
+		   sscanf(vo_geometry, "%i%%:%i%%", &xper, &yper) != 2 &&
+		   sscanf(vo_geometry, "%i%%", &xper) != 1)
+			return geometry_error();
+        }
+
+	if(xper >= 0 && xper <= 100) xoff = (scrw - vidw) * ((float)xper / 100.0);
+	if(yper >= 0 && yper <= 100) yoff = (scrh - vidh) * ((float)yper / 100.0);
 
-	*num = t;
+	/* FIXME: better checking of bounds... */
+	if(width < 0 || width > scrw) width = vidw;
+	if(height < 0 || height > scrh) height = vidh;
+	if(xoff < 0 || xoff + vidw > scrw) xoff = 0;
+	if(yoff < 0 || yoff + vidh > scrh) yoff = 0;
+
+	if(xpos) *xpos = xoff;
+	if(ypos) *ypos = yoff;
+	if(pwidth) *pwidth = width;
+	if(pheight) *pheight = height;
 	return 1;
 }
 
-int geometry(int *xpos, int *ypos, int scrw, int scrh, int vidw, int vidh, int fs)
+// compatibility function
+// only libvo working with full geometry options.
+int geometry(int *xpos, int *ypos, int scrw, int scrh, int vidw, int vidh)
 {
-	int xper = 0, yper = 0;
-	int glen;
-	char *colpos;
-
-	*xpos = 0; *ypos = 0;
-
-	if(vo_geometry == NULL)
-		return 1;
-
-	glen = strlen(vo_geometry);
-	colpos = strchr(vo_geometry, ':');
-	if(colpos == NULL)
-		colpos = (char *)(vo_geometry + glen);
-
-	/* Parse the x bit */
-	if(colpos[-1] == '%') {
-		if(!get_num(vo_geometry, &xper, colpos - 1))
-			return geometry_error();
-	} else {
-		if(!get_num(vo_geometry, xpos, colpos))
-			return geometry_error();
-	}
-
-	if(*colpos != '\0') {
-		if(vo_geometry[glen - 1] == '%') {
-			if(!get_num(colpos + 1, &yper, vo_geometry + glen - 1))
-				return geometry_error();
-		} else {
-			if(!get_num(colpos + 1, ypos, vo_geometry + glen))
-				return geometry_error();
-		}
-	}
-
-	if(xper)
-		*xpos = (scrw - vidw) * ((float)xper / 100.0);
-	if(yper)
-		*ypos = (scrh - vidh) * ((float)yper / 100.0);
-
-	if(*xpos + vidw > scrw) {
-		mp_msg(MSGT_VO, MSGL_ERR, "X position is too large\n");
-		return geometry_error();
-	}
-	if(*ypos + vidh > scrh) {
-		mp_msg(MSGT_VO, MSGL_ERR, "Y position is too large\n");
-		return geometry_error();
-	}
-
-	return 1;
+  return geometryFull(NULL, NULL, xpos, ypos, scrw, scrh, vidw, vidh);
 }
@@ -4,80 +4,58 @@
 
-/* A string of the form xpos[%]:ypos[%] */
+/* A string of the form [WxH][+X+Y] or xpos[%]:ypos[%] */
 char *vo_geometry = NULL;
 
